| TTR.PGM-package | R Documentation |
An implementation of the Thornley transport resistance plant growth model. The package can be used to simulate plant growth as forced by climate system variables. The package provides methods for formatting forcing variables, simulating growth dynamics and calibrating model parameters. For more information see Higgins et al. (2025) TTR.PGM: An R package for modelling the distributions and dynamics of plants using the Thornley transport resistance plant growth model. Methods in Ecology and Evolution. in press.
Maintainer: Steven Higgins steven.higgins@uni-bayreuth.de [copyright holder]
Other contributors:
Arne Burkhardt [contributor]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.